package tilingTypes.N5.Other;

import tilingTypes.SymmetryType;
import tilingTypes.TilingType;
import tilings.Functions;
import tilings.IFunction;

public class TilingTypeN5_07
   extends TilingType
{
   public TilingTypeN5_07(){
      super( "N5-7: Richard B. Kershner, 1968", 5, SymmetryType.pgg );

      paramMin = new int[]{ 60};
      paramMax = new int[]{180};
      paramDef = new int[]{110};
      paramName = new String[]{ "Angle 1" };

      // desc has: colour,   refcorner,corner2,   tile2Ix, tile2refcorner, tile2corner2,   mirrored
      description = new int[][]{
            {0, 0,0, 0,0,0, 0},
            {1, 0,4, 0,0,4, 1},
            {1, 2,1, 0,3,4, 0},
            {0, 0,4, 2,0,4, 1},

            {0, 3,2, 0,2,3, 0},
            {1, 0,4, 4,0,4, 1},
            {1, 2,1, 4,3,4, 0},
            {0, 0,4, 6,0,4, 1},
      };
      info = "b=c=d=e\nB+2E=360\n2C+D=360\n(2A+B+D=360)";
   }

   public void recalcBase(double[] paramValues) {
      double ln = .5;
      double d = paramValues[0];
      double a = 360-2*d;
      // find angle b s.t. angle e is correct
      double b = Functions.BisectionMethod(new Func(d), 120, 180, 0.001);
      double c = 360-2*b;

      double x2 = ln + ln*Math.cos( (180-a) * DEG2RAD);
      double y2 =      ln*Math.sin( (180-a) * DEG2RAD);
      double x3 = x2 + ln*Math.cos( (-a-b) * DEG2RAD);
      double y3 = y2 + ln*Math.sin( (-a-b) * DEG2RAD);
      double x4 = x3 + ln*Math.cos( (-a-b+180-c) * DEG2RAD);
      double y4 = y3 + ln*Math.sin( (-a-b+180-c) * DEG2RAD);

      baseTile.setPoint(0,  0,  0);
      baseTile.setPoint(1, ln,  0);
      baseTile.setPoint(2, x2, y2);
      baseTile.setPoint(3, x3, y3);
      baseTile.setPoint(4, x4, y4);
   }
   public void recalcOffsets(double[] paramValues) {
      offsets[0] = tiles[2].getX(3)-tiles[0].getX(0);
      offsets[1] = tiles[2].getY(3)-tiles[0].getY(0);
      offsets[2] = tiles[5].getX(3)-tiles[3].getX(1);
      offsets[3] = tiles[5].getY(3)-tiles[3].getY(1);
  }

   private class Func implements IFunction{
      private double d;
      public Func(double d0){ d=d0; }
      public double calculate(double b){
         // find angle b s.t. angle e is correct
         double a = 360-2*d;
         double c = 360-2*b;
         double e = b+d-180;

         double h = Math.sin((180-e)*DEG2RAD) + Math.sin((-a-e)*DEG2RAD);
         h -= Math.sin(d*DEG2RAD) + Math.sin((d-180+c)*DEG2RAD);
         return h;
      }
   }
}
